# WidgetTypeDto


## Enum

* `MARKDOWN` (value: `'markdown'`)

* `ANALYTICS_GRAPH` (value: `'analytics_graph'`)

* `TC_PIE_CHART` (value: `'tc_pie_chart'`)

* `AUTOMATION_TREND` (value: `'automation_trend'`)

* `AUTOMATION_TREND_V2` (value: `'automation_trend_v2'`)

* `STATISTIC_TREND` (value: `'statistic_trend'`)

* `TOP_TC` (value: `'top_tc'`)

* `TC_TREE_MAP` (value: `'tc_tree_map'`)

* `LAUNCH_LIST` (value: `'launch_list'`)

* `LAST_LAUNCH_PIE_CHART` (value: `'last_launch_pie_chart'`)

* `LAUNCH_TREND` (value: `'launch_trend'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


